@@ -147,14 +147,14 @@ bool addSourceAddress(std::map<boost::asio::ip::address, std::set<uint8_t>>& arr
                addressString, "0", boost::asio::ip::tcp::resolver::query::numeric_service);
             boost::asio::ip::tcp::resolver resolver(ios);
             boost::system::error_code ec;
-            const boost::asio::ip::tcp::resolver::results_type endpoints =
+            boost::asio::ip::tcp::resolver::iterator iterator =
                resolver.resolve(resolver_query, ec);
             if(ec) {
                std::cerr << "Failed to resolve a DNS name " << addressString << ": " << ec.message() << std::endl;
                exit(1);
             }
-            for (boost::asio::ip::tcp::resolver::iterator it = endpoints.cbegin(); it != endpoints.cend(); it++) {
-               const boost::asio::ip::tcp::endpoint endpoint = *it;
+            for(   ; iterator != boost::asio::ip::tcp::resolver::iterator(); iterator++) {
+               const boost::asio::ip::tcp::endpoint& endpoint = *iterator;
                HPCT_LOG(info) << addressString << " -> " << endpoint.address().to_string();
                addSourceAddress(array, endpoint.address().to_string(), false);
             }
@@ -215,14 +215,14 @@ bool addDestinationAddress(std::set<boost::asio::ip::address>& array,
             addressString, "0", boost::asio::ip::tcp::resolver::query::numeric_service);
          boost::asio::ip::tcp::resolver resolver(ios);
          boost::system::error_code ec;
-         const boost::asio::ip::tcp::resolver::results_type endpoints =
+         boost::asio::ip::tcp::resolver::iterator iterator =
             resolver.resolve(resolver_query, ec);
          if(ec) {
             std::cerr << "Failed to resolve a DNS name " << addressString << ": " << ec.message() << std::endl;
             exit(1);
          }
-         for (boost::asio::ip::tcp::resolver::iterator it = endpoints.cbegin(); it != endpoints.cend(); it++) {
-            const boost::asio::ip::tcp::endpoint endpoint = *it;
+         for(   ; iterator != boost::asio::ip::tcp::resolver::iterator(); iterator++) {
+            const boost::asio::ip::tcp::endpoint endpoint = *iterator;
             HPCT_LOG(info) << addressString << " -> " << endpoint.address().to_string();
             addDestinationAddress(array, endpoint.address().to_string(), false);
          }
